@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettings.py 11595 2019-05-29 06:39:53Z Andy $
+# $Id: AttachSettings.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-05-29 14:39:53 +0800 (週三, 29 五月 2019) $
-# $Revision: 11595 $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 import os
 
@@ -56,21 +56,23 @@ def attachSettings(settingsDict):
             staticDirs = []
         else:
             staticDirs = list(settingsDict.get('STATICFILES_DIRS'))
-        staticDirs.extend([THEOPHRUSTUS_STATIC_DIRS])
+        if settingsDict.get('THEOPHRUSTUS_STATIC_DIRS') == None:
+            staticDirs.append(THEOPHRUSTUS_STATIC_DIRS)            
         settingsDict['STATICFILES_DIRS'] = tuple(staticDirs)
         
         
         #=======================================================================
         # Attach TINYMCE_DEFAULT_CONFIG.
         #=======================================================================        
-        if not settingsDict.has_key('TINYMCE_DEFAULT_CONFIG'):
+        if 'TINYMCE_DEFAULT_CONFIG' not in settingsDict:
             settingsDict['TINYMCE_DEFAULT_CONFIG'] = {
                 'plugins':
-                    "facebook,autolink,lists,spellchecker,pagebreak,style,layer,table,save"
-                    ",advhr,advimage,advlink,emotions,iespell,inlinepopups,"
-                    "insertdatetime,preview,media,searchreplace,print,contextmenu,"
-                    "paste,directionality,fullscreen,noneditable,visualchars,"
-                    "nonbreaking,xhtmlxtras,template,upload,variablePlugin",
+                    "facebook,autolink,lists,spellchecker,pagebreak,style,"
+                    "layer,table,save,advhr,advimage,advlink,emotions,"
+                    "iespell,inlinepopups,insertdatetime,preview,media,"
+                    "searchreplace,print,contextmenu,paste,directionality"
+                    ",fullscreen,noneditable,visualchars,nonbreaking,"
+                    "xhtmlxtras,template,upload,variablePlugin",
                 'relative_urls': False,
                 'remove_script_host': False,
                 'skin_variant': "black",
@@ -87,23 +89,30 @@ def attachSettings(settingsDict):
                     'styles' : {'color' : '#ff0000'}
                 }],
 
-                #'formats': {"test": {"title" : 'Table row 1', "selector" : 'tr', "classes" : 'tablerow1'}},
+                #'formats': {"test": {"title" : 'Table row 1', \
+                #"selector" : 'tr', "classes" : 'tablerow1'}},
                 'theme': "advanced",
-                'theme_advanced_buttons1': "save,newdocument,|,bold,italic,underline,"
-                                           "strikethrough,|,justifyleft,justifycenter,"
-                                           "justifyright,justifyfull,|,styleselect,"
-                                           "formatselect,fontselect,fontsizeselect,"
-                                           "template,|,link,unlink,image,|,",
-                'theme_advanced_buttons2': "cut,copy,paste,pastetext,pasteword,|,search,"
-                                           "replace,|,bullist,numlist,|,outdent,indent,"
-                                           "blockquote,|,undo,redo,|,"
-                                           "upload,cleanup,code,|,insertdate,"
-                                           "inserttime,preview,|,forecolor,backcolor",
-                'theme_advanced_buttons3': "tablecontrols,|,hr,removeformat,visualaid,|,"
-                                           "sub,sup,|,charmap,iespell,media,advhr,|,"
-                                           "insertlayer,moveforward,movebackward,absolute,"
+                'theme_advanced_buttons1': "save,newdocument,|,bold,italic,"
+                                           "underline,strikethrough,|,"
+                                           "justifyleft,justifycenter,"
+                                           "justifyright,justifyfull,|,"
+                                           "styleselect,formatselect,"
+                                           "fontselect,fontsizeselect,template,"
+                                           "|,link,unlink,image,|,",
+                'theme_advanced_buttons2': "cut,copy,paste,pastetext,pasteword,"
+                                           "|,search,replace,|,bullist,"
+                                           "numlist,|,outdent,indent,"
+                                           "blockquote,|,undo,redo,|,upload,"
+                                           "cleanup,code,|,insertdate,"
+                                           "inserttime,preview,|,forecolor,"
+                                           "backcolor,",
+                'theme_advanced_buttons3': "tablecontrols,|,hr,removeformat,"
+                                           "visualaid,|,sub,sup,|,charmap,"
+                                           "iespell,media,advhr,|,insertlayer,"
+                                           "moveforward,movebackward,absolute,"
                                            "|,styleprops,spellchecker,",
-                'theme_advanced_buttons4': "fullscreen,print,feed,variablePlugin,|,",
+                'theme_advanced_buttons4': "fullscreen,print,feed,"
+                                           "variablePlugin,|,",
                 'theme_advanced_toolbar_location': "top",
                 'theme_advanced_toolbar_align': "left",
                 'theme_advanced_statusbar_location': "bottom",
@@ -117,7 +126,8 @@ def attachSettings(settingsDict):
                 #'content_css' : "css/example.css",
 
                 # Drop lists for link/image/media/template dialogs
-                #'template_external_list_url': "%sjs/TemplateExternalList.js" % MEDIA_URL,
+                #'template_external_list_url': "%sjs/TemplateExternalList.js"\
+                # % MEDIA_URL,
                 #'external_link_list_url': "js/link_list.js",
                 #'external_image_list_url': "js/image_list.js",
                 #'media_external_list_url': "js/media_list.js",
