@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: Mailer.py 11617 2019-06-07 05:01:17Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: Andy $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 11616 $
+# $Revision: 11617 $
 
 import os
 import re
@@ -117,7 +117,7 @@ class CloudSMTP(object):
 
             if attachments:
                 for (title, c, maintype) in attachments:
-                    mail.attach(utf8(title), c, maintype)
+                    mail.attach(str(title), c, maintype)
 
             mail.content_subtype = "mixed"
             if self.fakeTest:
