@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11560 2019-05-17 04:24:58Z Andy $
+# $Id: views.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,12 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-05-17 12:24:58 +0800 (週五, 17 五月 2019) $
-# $Revision: 11560 $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 import base64
 from datetime import datetime
-from urlparse import unquote
+from urllib.parse import unquote
 from cgi import parse_qsl
 
 from itertools import chain
