@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10827 2018-03-11 15:11:03Z David $
+# $Id: admin.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-11 23:11:03 +0800 (週日, 11 三月 2018) $
-# $Revision: 10827 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 from django import forms
 from django.contrib import admin
@@ -212,9 +212,9 @@ from emencia.django.newsletter.admin import ContactAdmin
 
 class ContactTheophrastusAdmin(ContactAdmin):
     list_display = (
-        'email', 'first_name', 'last_name', 'tags', 'tester', 'subscriber',
+        'email', 'first_name', 'last_name', 'tester', 'subscriber',
         'valid', 'total_subscriptions', 'formatedCreationDate',
-        'related_object_admin')
+        'related_object_admin')#'tags', 
 
     def formatedCreationDate(self, obj):
         return obj.creation_date.strftime("%Y-%m-%d %H:%M:%S")
