@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 9594 2016-03-18 12:59:58Z Judy $
+# $Id: models.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-18 20:59:58 +0800 (週五, 18 三月 2016) $
-# $Revision: 9594 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 from django.utils.translation import ugettext as _
 
@@ -31,16 +31,20 @@ def getStatisticsUrl(self):
 def getSubscriberUrl(self):
     return ('Theophrastus.views.displaySubscribers', (self.slug,))
 
-emModels.Newsletter.getStatisticsUrl = types.MethodType(
-    getStatisticsUrl, None, emModels.Newsletter)
+# emModels.Newsletter.getStatisticsUrl = types.MethodType(
+#     getStatisticsUrl, None, emModels.Newsletter)
+emModels.Newsletter.getStatisticsUrl = getStatisticsUrl
 
-emModels.Newsletter.getSubscriberUrl = types.MethodType(
-    getSubscriberUrl, None, emModels.Newsletter)
+# emModels.Newsletter.getSubscriberUrl = types.MethodType(
+    # getSubscriberUrl, None, emModels.Newsletter)
+emModels.Newsletter.getSubscriberUrl = getSubscriberUrl
 
 def getUnicode(self):
     if self.id == 1:
         return _("Cloud SMTP Server")
     return '%s (%s)' % (self.name, self.host)
 
-emModels.SMTPServer.__unicode__ = types.MethodType(
-    getUnicode, None, emModels.SMTPServer)
+# emModels.SMTPServer.__unicode__ = types.MethodType(
+    # getUnicode, None, emModels.SMTPServer)
+
+emModels.SMTPServer.__unicode__ = getUnicode
